@@ -1,13 +1,13 @@
 from collections import OrderedDict
 from copy import deepcopy
-from typing import Any, TypeVar, List, Optional, Type
-
-from dev_tools.meta.metaclasses import DeclarativeAttributesBaseMetaclass
-from dev_tools.template.mixins import TemplateObjectMixin, HttpRequestType
-from django.urls import resolve
+from typing import Any, TypeVar, List, Optional, Type, Tuple, Dict
 
 from action_set.components import BaseAction, ActionType, ActionButton
 from action_set.types import ActionSetDict
+from dev_tools.meta.metaclasses import DeclarativeAttributesBaseMetaclass
+from dev_tools.template.mixins import TemplateObjectMixin, HttpRequestType
+from django.urls import resolve
+from django.views import View
 
 
 class ActionsDeclarativeMetaclass(DeclarativeAttributesBaseMetaclass):
@@ -46,24 +46,26 @@ class ActionSet(BaseActionSet):
     Main class for grouping actions with custom template support.
     """
 
-    def __init__(self, request: HttpRequestType, action_set_group: Optional['ActionSetGroupType'] = None):
+    def __init__(self,
+                 request: HttpRequestType,
+                 action_set_group: Optional['ActionSetGroupType'] = None,
+                 filtered_actions: List[str] = None):
         super().__init__()
         self.request = request
         self.action_set_group = action_set_group
+        self.filtered_actions = filtered_actions
+
+        self._filter_actions()
 
     def _get_request(self) -> Optional[HttpRequestType]:
         return self.request
 
-
-class GroupedActionSet:
-    """
-    Mixin for adding Action Set grouper variable.
-    """
-
-    def __init__(self, action_set_group: 'ActionSetGroupType'):
-        self.action_set_group = action_set_group
-        request = action_set_group.request
-        super().__init__(request)
+    def _filter_actions(self) -> None:
+        new_actions = OrderedDict()
+        for action_name in self.filtered_actions or []:
+            new_actions[action_name] = self.actions[action_name]
+        if self.filtered_actions is not None:
+            self.actions = new_actions
 
 
 ActionSetType = TypeVar('ActionSetType', bound=ActionSet)
@@ -167,19 +169,24 @@ class ActionSetMenuMixin:
     Mixin for Action Set menu realization.
     """
 
-    url_attribute_name: str = 'data-url'
+    _MENU_ITEM_VIEW_ATTR: str = 'active_menu_items'
+
     activate_class: str = 'active'
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.view_class = resolve(self.request.path_info).func.view_class
         self.activate_menu_items()
 
     def activate_menu_items(self) -> None:
-        current_url_name = resolve(self.request.path_info).url_name
-        for name, action in self.actions.items():
-            item_url_name = resolve(action.html_params[self.url_attribute_name]).url_name
-            if item_url_name == current_url_name:
-                action.css_classes.append(self.activate_class)
+        active_menu_items = getattr(self.view_class, self._MENU_ITEM_VIEW_ATTR, [])
+        for name in active_menu_items:
+            if name in self.actions:
+                menu_item = self.actions[name]
+                self.activate_menu_item(menu_item)
+
+    def activate_menu_item(self, menu_item: Type[ActionType]) -> None:
+        menu_item.css_classes.append(self.activate_class)
 
 
 class BreadcrumbsSet(ActionSet):
@@ -190,19 +197,20 @@ class BreadcrumbsSet(ActionSet):
     crumb_class: Type[ActionType] = ActionButton
     active_crumb_css_class: str = ''
 
-    def __init__(self, view_kwargs: dict, crumbs_set: List[str], *args, **kwargs):
+    def __init__(self, view_kwargs: dict, *args, **kwargs):
         self.view_kwargs = view_kwargs
-        self.crumbs_set = crumbs_set
+        self.current_crumb_name = ''
         super().__init__(*args, **kwargs)
-        self.reset_crumbs()
 
-    def reset_crumbs(self):
+    def _filter_actions(self) -> None:
         new_actions = OrderedDict()
-        for crumb_name in self.crumbs_set:
+        for crumb_name in self.filtered_actions:
             prepared_crumb_name = crumb_name.replace('*', '')
             new_actions[prepared_crumb_name] = self.actions[prepared_crumb_name]
             if '*' in crumb_name:
-                new_actions[prepared_crumb_name].css_classes.append(self.active_crumb_css_class)
+                crumb = new_actions[prepared_crumb_name]
+                self.current_crumb_name = crumb.data
+                crumb.css_classes.append(self.active_crumb_css_class)
         self.actions = new_actions
 
 
